@@ -10,19 +10,19 @@
 #define __dcc_h__
 
 	void	close_all_dcc 		(void);
-	int	dcc_chat_active		(char *);
+	int	dcc_chat_active		(const char *);
 	void	dcc_chat_transmit 	(char *, char *, const char *, 
 						const char *, int);
-	void	dcc_check 		(fd_set *);
-	void	dcc_list 		(char *);
-	char *	dcc_raw_connect 	(char *, u_short);
-	char *	dcc_raw_listen 		(unsigned short);
-	void	dcc_reject 		(char *, char *, char *);
-	void	process_dcc 		(char *);
-	void	register_dcc_offer 	(char *, char *, char *, char *, 
-					 char *, char *, char *);
+	void	dcc_check 		(fd_set *, fd_set *);
+	BUILT_IN_COMMAND(dcc_cmd);
+	char *	dcc_raw_connect 	(const char *, const char *, int);
+	char *	dcc_raw_listen 		(int, unsigned short);
+	void	dcc_reject 		(const char *, char *, char *);
+	void	register_dcc_offer 	(const char *, char *, char *, char *, 
+					 char *, char *, char *, char *);
 	char *	DCC_get_current_transfer (void);
-	int	dcc_dead		(void);
+
+	char	*dccctl			(char *input);
 
 extern	time_t	dcc_timeout;
 
