@@ -49,15 +49,16 @@
 /*
  * Everybody needs these INET headers...
  */
-#ifdef USE_SOCKS5
-# include <socks.h>
-#endif
-# include <sys/socket.h>
+#include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
+#ifdef USE_SOCKS5
+# define INCLUDE_PROTOTYPES
+# include <socks.h>
+#endif
 
 
 /*
@@ -139,7 +140,9 @@
  * I took this from the autoconf documentation
  */
 #if defined(__GNUC__) && !defined(HAVE_ALLOCA_H)
-# define alloca __builtin_alloca
+# ifndef alloca
+#  define alloca __builtin_alloca
+# endif
 #else
 # if HAVE_ALLOCA_H
 #  include <alloca.h>
