@@ -1,4 +1,4 @@
-/* $EPIC: commands.c,v 1.80 2004/02/20 23:40:22 jnelson Exp $ */
+/* $EPIC: commands.c,v 1.85 2005/02/08 16:28:56 jnelson Exp $ */
 /*
  * commands.c -- Stuff needed to execute commands in ircII.
  *		 Includes the bulk of the built in commands for ircII.
@@ -395,11 +395,11 @@ BUILT_IN_COMMAND(away)
 	{
 		if ((*args == '-') || (*args == '/'))
 		{
-			arg = strchr(args, ' ');
-			if (arg)
-				*arg++ = '\0';
-			else
-				arg = empty_string;
+			arg = args;
+			while (*arg && !isspace(*arg))
+				arg++;
+			if (*arg)
+				*arg++ = 0;
 
 			if (0 == my_strnicmp(args+1, "A", 1))	/* all */
 			{
@@ -679,6 +679,7 @@ BUILT_IN_COMMAND(e_channel)
 BUILT_IN_COMMAND(e_nick)
 {
 	char	*nick;
+	const char *id;
 
 	if (!(nick = next_arg(args, &args)))
 	{
@@ -688,10 +689,14 @@ BUILT_IN_COMMAND(e_nick)
 		return;
 	}
 
-	if (!(nick = check_nickname(nick, 1)))
+	id = get_server_unique_id(from_server);
+	if (id == NULL || (my_stricmp(nick, id) && strcmp(nick, "0")))
 	{
+	    if (!(nick = check_nickname(nick, 1)))
+	    {
 		say("The nickname you specified is not a legal nickname.");
 		return;
+	    }
 	}
 
 	if (from_server == NOSERV)
@@ -871,8 +876,6 @@ BUILT_IN_COMMAND(echocmd)
 BUILT_IN_COMMAND(xechocmd)
 {
 	unsigned display;
-	int	lastlog_level = 0;
-	int	from_level = 0;
 	char	*flag_arg;
 	int	temp = 0;
 	Window *old_to_window;
@@ -3721,7 +3724,7 @@ static	unsigned 	level = 0;
 	}
 	else
 	{
-		char		*rest,
+		char 		*rest,
 				*alias = NULL,
 				*alias_name = NULL;
 		char		*cline;
@@ -3730,20 +3733,13 @@ static	unsigned 	level = 0;
 		IrcCommand	*command;
 		void		*arglist = NULL;
 
-		if ((rest = strchr(line, ' ')))
-		{
-			size_t size;
+		cline = LOCAL_COPY(line);
 
-			size = (rest - line) + 1;
-			cline = alloca(size);
-			strlcpy(cline, line, size);
+		rest = cline;
+		while (*rest && !isspace(*rest))
 			rest++;
-		}
-		else
-		{
-			cline = LOCAL_COPY(line);
-			rest = empty_string;
-		}
+		if (*rest)
+			*rest++ = 0;
 
 		upper(cline);
 
