@@ -1,4 +1,4 @@
-/* $EPIC: help.c,v 1.12 2004/02/20 23:40:23 jnelson Exp $ */
+/* $EPIC: help.c,v 1.13 2004/07/24 00:02:31 jnelson Exp $ */
 /*
  * help.c: handles the help stuff for irc 
  *
@@ -735,6 +735,8 @@ static	void create_help_window (void)
 		help_window->holding_top_of_display = NULL;
 		recalculate_window_cursor_and_display_ip(help_window);
 		help_window->window_level = LOG_HELP;
+		window_body_needs_redraw(help_window);
+		window_statusbar_needs_redraw(help_window);
 		update_all_windows();
 	}
 	else
