@@ -18,13 +18,6 @@ cat > info.c << __E__O__F__
  * info.c -- info about who compiled this version.
  * This file is auto-magically created.   Changes will be nuked.
  */
-
-#ifdef __STDC__
-#define my_paste(x, y, z) x ## y ## z
-#else
-#define my_paste(x, y, z) x/**/y/**/z
-#endif
-
 #include "config.h"
 #ifdef ANONYMOUS_COMPILE
 #define USER "<anonymous>"
@@ -36,6 +29,6 @@ const char *compile_user = "$comp_user";
 const char *compile_host = "$comp_host";
 const char *compile_time = "$comp_time";
 const char *info_c_sum   = "$info_c_sum";
-const char *compile_info = my_paste("Compiled by ", USER, "@$comp_host on $comp_time");
+const char *compile_info = "Compiled by " USER "@$comp_host on $comp_time";
 
 __E__O__F__
