@@ -1,4 +1,4 @@
-/* $EPIC: numbers.c,v 1.62 2004/02/06 04:48:54 jnelson Exp $ */
+/* $EPIC: numbers.c,v 1.70 2006/12/08 15:47:50 jnelson Exp $ */
 /*
  * numbers.c: handles all those strange numeric response dished out by that
  * wacky, nutty program we call ircd 
@@ -96,13 +96,15 @@ const char *	banner (void)
  * Simplified by Jeremy Nelson (esl) some time in 1996.
  * -- called by more than one place.
  */
-void 	display_msg (const char *from, const char **ArgList)
+static void 	display_msg (const char *from, const char *comm, const char **ArgList)
 {
 	char	*ptr = NULL;
 	const char	*rest;
 	int	drem;
 
-	rest = PasteArgs(ArgList, 0);
+	if (!(rest = PasteArgs(ArgList, 0)))
+		{ rfc1459_odd(from, comm, ArgList); return; }
+
 	if (from && (my_strnicmp(get_server_itsname(from_server), from,
 			strlen(get_server_itsname(from_server))) == 0))
 		from = NULL;
@@ -181,6 +183,10 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 	/* All numerics must have a target (our nickname) */
 	if (!comm || !*comm)
 		{ rfc1459_odd(from, comm, ArgList); return; }
+	numeric = atol(comm);
+	if (numeric < 0 || numeric > 999)
+		{ rfc1459_odd(from, comm, ArgList); return; }
+
 	if (!(target = ArgList[0]))
 		{ rfc1459_odd(from, comm, ArgList); return; }
 	ArgList++;
@@ -191,7 +197,6 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 	else
 		message_from(NULL, LOG_CRAP);
 
-	numeric = atol(comm);
 	current_numeric = -numeric;	/* must be negative of numeric! */
 
 	/*
@@ -220,6 +225,12 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 	 */
 	case 001:	/* #define RPL_WELCOME          001 */
 	{
+		Timeval i;
+
+                i.tv_sec = 0;
+                i.tv_usec = 50000;
+                select(0, NULL, NULL, NULL, &i);
+
 		accept_server_nickname(from_server, target);
 		server_is_registered(from_server, 1);
 		userhostbase(from_server, NULL, got_my_userhost, 1);
@@ -327,6 +338,24 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 		goto END;
 	}
 
+	case 42:		/* ircnet's "unique id" numeric	042 */
+	{
+		const char *	unique_id;
+		const char *	message;
+
+		PasteArgs(ArgList, 1);
+		if (!(unique_id = ArgList[0]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		else if (!(message = ArgList[1]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+
+		set_server_unique_id(from_server, unique_id);
+		if (do_hook(current_numeric, "%s %s %s", 
+					from, unique_id, message))
+			goto DISPLAY;
+		goto END;
+	}
+
         case 301:               /* #define RPL_AWAY             301 */
         {
 		const char *nick, *message;
@@ -569,10 +598,15 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 		xwhoreply(from_server, NULL, comm, ArgList);
 		goto END;
 
+	/* XXX Yea yea, these are out of order. so shoot me. */
+	case 346:		/* #define RPL_INVITELIST (+I for erf) */
+	case 348:		/* #define RPL_EXCEPTLIST (+e for erf) */
 	case 367:		/* #define RPL_BANLIST */
 		number_of_bans++;
 		break;
 
+	case 347:		/* #define END_OF_INVITELIST */
+	case 349:		/* #define END_OF_EXCEPTLIST */
 	case 368:		/* #define END_OF_BANLIST */
 	{
 		const char	*channel;
@@ -590,9 +624,14 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 		if (do_hook(current_numeric, "%s %d %s", 
 				from, number_of_bans, channel))
 #endif
-			put_it("%s Total number of bans on %s - %d",
-				banner(), channel, number_of_bans);
-
+		{
+			put_it("%s Total number of %s on %s - %d",
+				banner(), 
+				 numeric == 347 ? "invites" :
+				(numeric == 349 ? "exceptions" :
+				(numeric == 368 ? "bans" : "wounds")),
+				channel, number_of_bans);
+		}
 		goto END;
 	}
 
@@ -1092,7 +1131,7 @@ DISPLAY:
 	{
 		PasteArgs(ArgList, 0);
 		if (get_int_var(SHOW_END_OF_MSGS_VAR))
-			display_msg(from, ArgList);
+			display_msg(from, comm, ArgList);
 		break;
 	}
 
@@ -1290,7 +1329,7 @@ DISPLAY:
 		if (!(channel = ArgList[1]))
 			{ rfc1459_odd(from, comm, ArgList); goto END; }
 		if (!(line = ArgList[2]))
-			{ rfc1459_odd(from, comm, ArgList); goto END; }
+			{ line = empty_string; }
 
 		/* This is only for when the user joined the channel */
 		if (channel_is_syncing(channel, from_server))
@@ -1372,12 +1411,14 @@ DISPLAY:
 			{ rfc1459_odd(from, comm, ArgList); goto END; }
 
 		if (!channel_is_syncing(channel, from_server))
-			display_msg(from, ArgList);
+			display_msg(from, comm, ArgList);
 
 		break;
 	}
 
-	case 367:
+	case 346:		/* +I on erf */
+	case 348:		/* +e on erf */
+	case 367:		/* +b */
 	{
 		const char	*channel, *ban, *perp, *when_str;
 		time_t	howlong;
@@ -1424,7 +1465,7 @@ DISPLAY:
 	{
 		PasteArgs(ArgList, 0);
 		if (get_int_var(SHOW_END_OF_MSGS_VAR))
-			display_msg(from, ArgList);
+			display_msg(from, comm, ArgList);
 		break;
 	}
 
@@ -1495,7 +1536,7 @@ DISPLAY:
 		/* IRCnet has a different 477 numeric. */
 		if (message && *message == '+')
 		{
-			display_msg(from, ArgList);
+			display_msg(from, comm, ArgList);
 			break;
 		}
 
@@ -1506,7 +1547,7 @@ DISPLAY:
 	}
 
 	default:
-		display_msg(from, ArgList);
+		display_msg(from, comm, ArgList);
 	}
 
 END:
@@ -1517,6 +1558,8 @@ END:
 	 */
 	switch (numeric)
 	{
+	case 347:		/* #define END_OF_INVITELIST */
+	case 349:		/* #define END_OF_EXCEPTLIST */
 	case 368:
 		number_of_bans = 0;
 		break;
