@@ -1,4 +1,4 @@
-/* $EPIC: screen.c,v 1.65 2003/12/07 20:16:52 jnelson Exp $ */
+/* $EPIC: screen.c,v 1.72 2004/12/01 23:47:51 jnelson Exp $ */
 /*
  * screen.c
  *
@@ -1800,7 +1800,10 @@ const 	u_char	*ptr;
 				int	lhs_count = 0;
 				int	continued_count = 0;
 
-				if (do_indent && (indent < (max_cols / 3)) &&
+				if (indent > max_cols / 3)
+					indent = max_cols / 3;
+
+				if (do_indent && 
 					((int)strlen(cont_ptr) < indent))
 				{
 					size_t size = indent + 10;;
@@ -1896,6 +1899,7 @@ const 	u_char	*ptr;
 			strlcpy(buffer, cont, sizeof(buffer) / 2);
 			display_attributes(buffer + strlen(buffer), &saved_a);
 			strlcat(buffer, pos_copy, sizeof(buffer) / 2);
+			display_attributes(buffer + strlen(buffer), &a);
 
 			pos = strlen(buffer);
 			/* Watch this -- ugh. how expensive! :( */
@@ -2303,11 +2307,23 @@ static void 	add_to_window (Window *window, const unsigned char *str)
 
 	if (!privileged_output)
 	{
+	   static int recursion = 0;
+
 	   if (!do_hook(WINDOW_LIST, "%u %s", window->refnum, str))
 		return;
 
-	   if ((pend = get_string_var(OUTPUT_REWRITE_VAR)))
+	   /* 
+	    * If output rewriting causes more output, (such as a stray error
+	    * message) allow a few levels of nesting [just to be kind], but 
+	    * cut the recursion off at its knees at 5 levels.  This is an 
+	    * entirely arbitrary value.  Change it if you wish.
+	    * (Recursion detection by larne in epic4-2.1.3)
+	    */
+	   recursion++;
+	   if (recursion < 5)
 	   {
+	     if ((pend = get_string_var(OUTPUT_REWRITE_VAR)))
+	     {
 		char	*prepend_exp;
 		char	argstuff[10240];
 		int	args_flag;
@@ -2322,7 +2338,9 @@ static void 	add_to_window (Window *window, const unsigned char *str)
 
 		str = prepend_exp;
 		free_me = prepend_exp;
+	     }
 	   }
+	   recursion--;
 
 	   /* Normalize the line of output */
 	   strval = normalize_string(str, 0);
